@@ -34,12 +34,17 @@ class PrinterDelegate: public QStyledItemDelegate
     Q_OBJECT
 
 public:
-    PrinterDelegate(QObject *parent = 0);
+    explicit PrinterDelegate(QObject *parent = 0);
 
     void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const;
     QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const;
 
 private:
+    int m_favIconSize;
+    int m_emblemIconSize;
+    int m_universalPadding;
+    int m_fadeLength;
+    int m_mainIconSize;
     int calcItemHeight(const QStyleOptionViewItem &option) const;
 };
 
